@@ -1,5 +1,5 @@
 /* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
- * $Id: TabCanvas.cpp 2686 2018-12-05 16:40:06Z stephane $
+ * $Id: TabCanvas.cpp 2687 2018-12-06 21:15:40Z stephane $
  */
 
 #include "GMM.hpp"
@@ -19,6 +19,8 @@ TabCanvas::TabCanvas(const std::string & name) :
 	time_since_run_changed(std::time(nullptr)),
 	time_since_pkg_changed(std::time(nullptr)),
 	time_since_last_board(std::time(nullptr)),
+	time_since_last_board_warning(0),
+	number_of_boards_when_warning_was_last_issued(0),
 	timer_frequency_in_milliseconds(cfg().get_int(prefix + "_chart_redraw_ms")),
 	comm_handle(INVALID_HANDLE_VALUE),
 	current_kiln(0),
@@ -264,6 +266,35 @@ void TabCanvas::periodic_update(void)
 		run_number_of_boards_editor.setTooltip(tooltip);
 	}
 
+	if (cfg().get_bool("warn_if_package_contains_too_many_boards"))
+	{
+		const size_t number_of_boards_in_package = pkg_doubles.size();
+		if (number_of_boards_in_package > cfg().get_int("warn_board_threshold"))
+		{
+			if (number_of_boards_in_package > number_of_boards_when_warning_was_last_issued)
+			{
+				if (std::time(nullptr) - time_since_last_board_warning > cfg().get_int("warn_seconds_between_warnings"))
+				{
+					const std::string name = cfg().get_str(prefix + "_name");
+					const std::string text =
+						"The number of boards for " + name + " is unusually high.\r\n"
+						"\r\n"
+						"- Run: #"		+ run_editor.getText().toStdString()			+ "\r\n"
+						"- Pkg: #"		+ pkg_editor.getText().toStdString()			+ "\r\n"
+						"- Boards: "	+ std::to_string(number_of_boards_in_package)	+ "\r\n"
+						"\r\n"
+						"Please verify that the GMM OPC Console is still running and communication with RSLinx has not been lost.";
+
+					LOG_MSG("prefix=" << prefix << ": " << text);
+
+					AlertWindow::showMessageBox(AlertWindow::AlertIconType::WarningIcon, "GMM - " + name, text);
+					time_since_last_board_warning = std::time(nullptr);
+					number_of_boards_when_warning_was_last_issued = number_of_boards_in_package;
+				}
+			}
+		}
+	}
+
 	return;
 }
 
@@ -1093,6 +1124,8 @@ void TabCanvas::update_kiln_run_pkg(void)
 			pkg_sum		= 0.0;
 			pkg_average	= 0.0;
 			pkg_std_dev	= 0.0;
+			time_since_last_board_warning = 0;
+			number_of_boards_when_warning_was_last_issued = 0;
 		}
 		if (run_needs_to_be_reset)
 		{
